@@ -269,6 +269,7 @@ zenity_tree (ZenityData *data, ZenityTreeData *tree_data)
 {
   GtkWidget *dialog;
   GtkWidget *tree_view;
+  GtkWidget *text;
   GtkTreeViewColumn *column;
   GtkListStore *model;
   GType *column_types;
@@ -303,6 +304,11 @@ zenity_tree (ZenityData *data, ZenityTreeData *tree_data)
   if (data->dialog_title)
     gtk_window_set_title (GTK_WINDOW (dialog), data->dialog_title);
 
+  text = glade_xml_get_widget (glade_dialog, "zenity_tree_text");
+                                                                                
+  if (tree_data->dialog_text)
+  gtk_label_set_text (GTK_LABEL (text), tree_data->dialog_text);
+
   if (data->window_icon)
     zenity_util_set_window_icon (dialog, data->window_icon);
   else
@@ -437,7 +443,7 @@ zenity_tree (ZenityData *data, ZenityTreeData *tree_data)
       zenity_tree_fill_entries_from_stdin (GTK_TREE_VIEW (tree_view), n_columns, FALSE, tree_data->editable);
   }
 
-  gtk_widget_show (dialog);
+  zenity_util_show_dialog (dialog);
   gtk_main ();
 
   if (glade_dialog)
