@@ -31,6 +31,14 @@ typedef struct {
   gint   exit_code;
 } ZenityData;
 
+typedef enum {
+  ZENITY_OK,
+  ZENITY_CANCEL,
+  ZENITY_ESC,
+  ZENITY_ERROR,
+  ZENITY_EXTRA
+} ZenityExitCode;
+
 typedef struct {
   gchar *dialog_text;
   gint   day;
@@ -53,6 +61,8 @@ typedef struct {
 
 typedef struct {
   gchar	*uri;
+  gboolean multi;
+  gchar *separator;
 } ZenityFileData;
 
 typedef struct {
@@ -65,6 +75,7 @@ typedef struct {
   gchar        *dialog_text;
   gchar        *entry_text;
   gboolean      pulsate;
+  gboolean	autoclose;
   gdouble       percentage;
 } ZenityProgressData;
 
